subroutine check_g_real
    !check that KS wavefunctions are orthonormal
    !in G space
    !gamma only case
    !only for norm-conserving pseudo-potentials
    !no spin-polarised case

    use kinds, only : DP
    use io_global, only : stdout
    USE wavefunctions, ONLY : evc
    USE io_files, ONLY : prefix, tmp_dir, nwordwfc,iunwfc
    USE wvfct,                ONLY : nbnd, npwx, npw
    USE gvect,                ONLY :gstart
    USE mp_world,  ONLY :  world_comm
    USE mp, ONLY : mp_sum
    use io_global, ONLY : stdout, ionode

    implicit none

    real(kind=DP), allocatable :: omat(:,:)
    integer :: ii,jj

    integer ::iun
    INTEGER, EXTERNAL :: find_free_unit

    !read in wfc

    CALL davcio(evc,2*nwordwfc,iunwfc,1,-1)

!   calculate overlap matrix
    allocate(omat(nbnd,nbnd))

    call dgemm('T','N',nbnd,nbnd,2*npw,2.d0,evc,2*npwx,evc,2*npwx,0.d0,omat,nbnd)
    if(gstart==2) then
        do ii=1,nbnd
            do jj=1,nbnd
                omat(jj,ii)=omat(jj,ii)-dble(conjg(evc(1,ii))*evc(1,jj))
            enddo
        enddo
    endif

    call mp_sum(omat, world_comm)

!write on screen
    do ii=1,nbnd
        do jj=1,nbnd
            write(stdout,*) 'OVERLAP:', ii,jj,omat(ii,jj)
        enddo
    enddo   

!write on disk
    iun = find_free_unit()
    if(ionode) then
        open(unit=iun,file='overlap.dat',status='unknown')
        do ii=1,nbnd
            do jj=1,nbnd
                write(iun,*)  ii,jj,omat(ii,jj)
            enddo
        enddo  
        close(iun)
    endif


    deallocate(omat)
    !

    return

end subroutine


subroutine check_g_real_file(prefix_file)
    !calcule overlap of wavefunctions with 
    !wavefunctions read from file
    !in G space
    !gamma only case
    !only for norm-conserving pseudo-potentials
    !no spin-polarised case

    use kinds, only : DP
    use io_global, only : stdout
    USE wavefunctions, ONLY : evc
    USE io_files, ONLY : prefix, tmp_dir, nwordwfc,iunwfc
    USE wvfct,                ONLY : nbnd, npwx, npw
    USE gvect,                ONLY :gstart
    USE mp_world,  ONLY :  world_comm
    USE mp, ONLY : mp_sum
    use io_global, ONLY : stdout, ionode


    implicit none

    interface
     subroutine diropn_file (unit, extension, recl, exst, tmp_dir_, prefix_file)
        character(len=*) :: extension
        character(len=*), optional :: tmp_dir_
        character(len=*), optional :: prefix_file
        integer :: unit
        integer :: recl
        logical :: exst
     end subroutine
    end interface


    character(len=256), intent(in) :: prefix_file

    real(kind=DP), allocatable :: omat(:,:)
    complex(kind=DP), allocatable :: evc_file(:,:)

    integer :: ii,jj

    integer ::iun, iunfile
    INTEGER, EXTERNAL :: find_free_unit
    logical :: exst


    
    !read wavefunctions from file

    allocate(evc_file(npw,nbnd))

    iunfile = find_free_unit()
    CALL diropn_file( iunfile, 'wfc', 2*nwordwfc, exst,prefix_file=prefix_file )     
    CALL davcio(evc_file,2*nwordwfc,iunfile,1,-1)
    close(iunfile)

    !read wavefunction

    CALL davcio(evc,2*nwordwfc,iunwfc,1,-1)


    !calculate overlap matrix
    allocate(omat(nbnd,nbnd))

    call dgemm('T','N',nbnd,nbnd,2*npw,2.d0,evc_file,2*npwx,evc,2*npwx,0.d0,omat,nbnd)
    if(gstart==2) then
        do ii=1,nbnd
            do jj=1,nbnd
                omat(jj,ii)=omat(jj,ii)-dble(conjg(evc_file(1,ii))*evc(1,jj))
            enddo
        enddo
    endif

    call mp_sum(omat, world_comm)

!write on screen
    do ii=1,nbnd
        do jj=1,nbnd
            write(stdout,*) 'OVERLAP:', ii,jj,omat(ii,jj)
        enddo
    enddo   



    deallocate(evc_file)

    return
end subroutine

subroutine diropn_file (unit, extension, recl, exst, tmp_dir_, prefix_file)
    !-----------------------------------------------------------------------
    !! Opens a direct-access file named "prefix"."extension" in directory
    !! \(\text{tmp_dir_}\) if specified, in "tmp\_dir" otherwise.  
    !! In parallel execution, the node number is added to the file name.
    !! The record length is \(\text{recl}\) double-precision numbers.
    !! On output, \(\text{exst}\) is TRUE if opened file already exists.
    !! If \(\text{recl}=-1\), the file existence is checked, nothing else
    !! is done.
    !
    USE io_files 

    implicit none
    !
    !    first the input variables
    !
    character(len=*) :: extension
    !! input: name of the file to open
    character(len=*), optional :: tmp_dir_
    !! optional variable, if present it is used as tmp_dir
    character(len=*), optional :: prefix_file
    !! optional variable, if present it is used as tmp_dir
    integer :: unit
    !! input: unit of the file to open
    integer :: recl
    !! input: length of the records
    logical :: exst
    !! output: if true the file exists
    !
    !    local variables
    !
    character(len=320) :: tempfile
    ! complete file name
    real(dp):: dummy
    integer*8 :: unf_recl
    ! double precision to prevent integer overflow
    integer :: ios, direct_io_factor
    logical :: opnd
    !
    !    initial checks
    !
    if (unit < 0) call errore ('diropn', 'wrong unit', 1)
    !
    !    ifirst we check that the file is not already openend
    !
    ios = 0
    inquire (unit = unit, opened = opnd)
    if (opnd) call errore ('diropn', "can't open a connected unit", abs(unit))
    !
    !    then we check the filename extension
    !
    if (extension == ' ') call errore ('diropn','filename extension not given',2)
    if (present(tmp_dir_)) then
       tempfile = trim(tmp_dir_)// trim(prefix_file) //"."// trim(extension)//nd_nmbr
    else
       tempfile = trim(tmp_dir) // trim(prefix_file) //"."// trim(extension)//nd_nmbr
    endif
  
    inquire (file = tempfile, exist = exst)
    if (recl == -1) RETURN
    !
    ! the  record length in direct-access I/O is given by the number of
    ! real*8 words times direct_io_factor (may depend on the compiler)
    !
    INQUIRE (IOLENGTH=direct_io_factor) dummy
    unf_recl = direct_io_factor * int(recl, kind=kind(unf_recl))
    if (unf_recl <= 0) call errore ('diropn', 'wrong record length', 3)
    !
    open (unit, file=trim(adjustl(tempfile)), iostat=ios, form='unformatted', &
         status = 'unknown', access = 'direct', recl = unf_recl)
  
    if (ios /= 0) call errore ('diropn', 'error opening '//trim(tempfile), unit)
    return
    !-----------------------------------------------------------------------
  end subroutine diropn_file
  !-----------------------------------------------------------------------