!-----------------------------------------------------------------------
program school
  !!-----------------------------------------------------------------------
  !! 
  !! input:  namelist "&inputsimple", with variables
  !!   prefix       prefix of input files saved by program pwscf
  !!   outdir       temporary directory where files resides
  !!    
  use io_files,  ONLY : prefix, tmp_dir
  use io_global, ONLY : stdout, ionode, ionode_id
  USE mp_global, ONLY: mp_startup
  USE mp_pools, ONLY : kunit
  use mp_world, ONLY: mpime, world_comm 
  USE environment,   ONLY: environment_start
  USE mp, ONLY : mp_bcast
  USE io_files, ONLY :  nwordwfc,iunwfc
  USE wavefunctions, ONLY : evc
    
  
  
  !
  IMPLICIT NONE
  CHARACTER(len=9) :: code = 'SCHOOL'
  INTEGER :: ios, kunittmp
  CHARACTER(LEN=256), EXTERNAL :: trimcheck
  CHARACTER(len=200) :: pp_file
  LOGICAL :: uspp_spsi, ascii, single_file, raw
  LOGICAL :: exst
  INTEGER, EXTERNAL :: find_free_unit
  CHARACTER(LEN=256) :: outdir
  LOGICAL :: lsecfile=.false.
  CHARACTER(LEN=256) :: prefix_file
  !
  !
  NAMELIST /inputschool/ prefix,outdir,lsecfile, prefix_file
  !
  CALL mp_startup ( )
  CALL environment_start ( code )
  !
  CALL start_clock('school')
  !
  CALL get_environment_variable( 'ESPRESSO_TMPDIR', outdir )
  IF ( TRIM( outdir ) == ' ' ) outdir = './'
  IF ( ionode ) THEN
     CALL input_from_file ( )
     READ(5,inputschool,IOSTAT=ios)
     IF (ios /= 0) CALL errore ('SCHOOL', 'reading inputschool: namelist', ABS(ios) )
  ENDIF
  !

  tmp_dir = trimcheck( outdir )
  CALL mp_bcast( outdir, ionode_id, world_comm  )
  CALL mp_bcast( tmp_dir, ionode_id , world_comm )
  CALL mp_bcast( prefix, ionode_id, world_comm  )
  CALL mp_bcast( lsecfile, ionode_id, world_comm  )
  CALL mp_bcast( prefix_file, ionode_id, world_comm  )

 CALL read_file
  !
 CALL openfile_school
  !
#if defined __MPI
  kunittmp = kunit
#else
    kunittmp = 1
#endif
  !
  pp_file= ' '
  uspp_spsi = .FALSE.
  ascii = .FALSE.
  single_file = .FALSE.
  raw = .FALSE.
  
  CALL read_export(pp_file,kunittmp,uspp_spsi, ascii, single_file, raw)
  
  CALL summary()
  !
  CALL print_ks_energies()
  CALL davcio(evc,2*nwordwfc,iunwfc,1,1)
  
  !
  call check_g_real
  if(lsecfile)  then 
      call check_g_real_file(prefix_file)
  endif
  !
  CALL stop_clock('school')
  CALL print_clock('school')
  
  !
  CALL stop_pp_school
  STOP
  !
END PROGRAM school



subroutine stop_pp_school
  !--------------------------------------------------------------------
  !! Synchronize processes before stopping.
  !
  use io_files, only: iunwfc
  use mp_global, only: mp_global_end
  USE parallel_include
#if defined(__MPI)

  integer :: info
  logical :: op

  inquire ( iunwfc, opened = op )

  if ( op ) close (unit = iunwfc)

  call mp_global_end( )

#endif
 
  stop
end subroutine stop_pp_school